@@ -1,4 +1,4 @@
 from micawber.cache import Cache, PickleCache
 from micawber.exceptions import ProviderException
 from micawber.parsers import extract, extract_html, parse_text, parse_text_full, parse_html
-from micawber.providers import Provider, ProviderRegistry, bootstrap_basic, bootstrap_embedly
+from micawber.providers import Provider, ProviderRegistry, bootstrap_basic, bootstrap_embedly, bootstrap_noembed
